
from setuptools import setup

setup(package_data={'icalendar-stubs': ['__init__.pyi', 'alarms.pyi', 'attr.pyi', 'cal.pyi', 'caselessdict.pyi', 'enums.pyi', 'error.pyi', 'param.pyi', 'parser.pyi', 'parser_tools.pyi', 'prop.pyi', 'timezone/__init__.pyi', 'timezone/equivalent_timezone_ids.pyi', 'timezone/equivalent_timezone_ids_result.pyi', 'timezone/provider.pyi', 'timezone/pytz.pyi', 'timezone/tzid.pyi', 'timezone/tzp.pyi', 'timezone/windows_to_olson.pyi', 'timezone/zoneinfo.pyi', 'tools.pyi', 'version.pyi', 'METADATA.toml', 'py.typed']})
